summaryrefslogtreecommitdiffstats
path: root/templates/annotated/menuapp1.py
diff options
context:
space:
mode:
Diffstat (limited to 'templates/annotated/menuapp1.py')
-rw-r--r--templates/annotated/menuapp1.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/templates/annotated/menuapp1.py b/templates/annotated/menuapp1.py
index d18ea00..faa8662 100644
--- a/templates/annotated/menuapp1.py
+++ b/templates/annotated/menuapp1.py
@@ -45,7 +45,7 @@ import sys
from qt import TQPopupMenu, SIGNAL
-from tdecore import TDEApplication, KCmdLineArgs, KAboutData, i18n, KStdAccel, KIcon, KIconLoader
+from tdecore import TDEApplication, TDECmdLineArgs, KAboutData, i18n, KStdAccel, KIcon, KIconLoader
from tdeui import KMainWindow, KMessageBox
TOOLBAR_NEW = 1
@@ -136,7 +136,7 @@ class MainWin (KMainWindow):
# Let KDE generate a nifty help menu
# The KAboutData/KCmdLineArgs data from the main part of the program
# will be used to generate the About dialog
helpMenu = self.helpMenu ("")
@@ -247,7 +247,7 @@ class MainWin (KMainWindow):
# See athe minimal.py and basicapp.py templates for
# explantion of the basic app and main window setup
# The following data is passed to KCmdLineArgs, which in
# turn makes it available to the "about" box in the Help
# menu (when the Help menu is created as above)
@@ -260,9 +260,9 @@ aboutData = KAboutData ("", "",\
aboutData.addAuthor ("author1", "whatever they did", "email@somedomain")
aboutData.addAuthor ("author2", "they did something else", "another@email.address")
-KCmdLineArgs.init (sys.argv, aboutData)
+TDECmdLineArgs.init (sys.argv, aboutData)
-KCmdLineArgs.addCmdLineOptions ([("+files", "File to open")])
+TDECmdLineArgs.addCmdLineOptions ([("+files", "File to open")])
app = TDEApplication ()
mainWindow = MainWin (None, "main window")
@@ -136,7 +136,7 @@ class MainWin (KMainWindow):
# Let KDE generate a nifty help menu
- # The KAboutData/KCmdLineArgs data from the main part of the program
+ # The KAboutData/TDECmdLineArgs data from the main part of the program
# will be used to generate the About dialog
helpMenu = self.helpMenu ("")
@@ -247,7 +247,7 @@ class MainWin (KMainWindow):
# See athe minimal.py and basicapp.py templates for
# explantion of the basic app and main window setup
-# The following data is passed to KCmdLineArgs, which in
+# The following data is passed to TDECmdLineArgs, which in
# turn makes it available to the "about" box in the Help
# menu (when the Help menu is created as above)